@@ -1,7 +1,7 @@
 package apis
 
 import (
-	"github.com/openshift-knative/knative-serving-operator/pkg/apis/serving/v1alpha1"
+	"github.com/openshift-knative/serverless-operator/serving/operator/pkg/apis/serving/v1alpha1"
 )
 
 func init() {
